ZERO_32BYTES = b"\x00" * 32
ZERO_ADDRESS = b"\x00" * 20


def make_receipt(
    transaction_hash=ZERO_32BYTES,
    transaction_index=0,
    block_number=0,
    block_hash=ZERO_32BYTES,
    cumulative_gas_used=0,
    _from=ZERO_ADDRESS,
    gas_used=21000,
    effective_gas_price=1000000000,
    contract_address=None,
    logs=None,
    state_root=b"\x00",
    status=0,
    to=ZERO_ADDRESS,
    _type="0x0",
):
    return {
        "transaction_hash": transaction_hash,
        "transaction_index": transaction_index,
        "block_number": block_number,
        "block_hash": block_hash,
        "cumulative_gas_used": cumulative_gas_used,
        "from": _from,
        "gas_used": gas_used,
        "effective_gas_price": effective_gas_price,
        "contract_address": contract_address,
        "logs": logs or [],
        "state_root": state_root,
        "status": status,
        "to": to,
        "type": _type,
    }



from __future__ import absolute_import

from importlib import import_module


def import_string(dotted_path):
    """
    Source: django.utils.module_loading

    Import a dotted module path and return the attribute/class designated by the
    last name in the path. Raise ImportError if the import failed.
    """
    try:
        module_path, class_name = dotted_path.rsplit(".", 1)
    except ValueError:
        msg = "%s doesn't look like a module path" % dotted_path
        raise ImportError(msg)

    module = import_module(module_path)

    try:
        return getattr(module, class_name)
    except AttributeError:
        msg = 'Module "{}" does not define a "{}" attribute/class'.format(
            module_path, class_name
        )
        raise ImportError(msg)


def get_import_path(obj):
    return ".".join(
        (
            obj.__module__,
            obj.__name__,
        )
    )
